<?php

namespace Status\Status\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Status\Status\Models\Status;

class StatusPolicy
{

    /**
     * Determine if the given user can view the status.
     *
     * @param UserPolicyInterface $authUser
     * @param Status $status
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Status $status)
    {
        if ($authUser->canDo('status.status.view') && $authUser->isAdmin()) {
            return true;
        }

        return $status->user_id == user_id() && $status->user_type == user_type();
    }

    /**
     * Determine if the given user can create a status.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('status.status.create');
    }

    /**
     * Determine if the given user can update the given status.
     *
     * @param UserPolicyInterface $authUser
     * @param Status $status
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Status $status)
    {
        if ($authUser->canDo('status.status.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $status->user_id == user_id() && $status->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given status.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Status $status)
    {
        return $status->user_id == user_id() && $status->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given status.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Status $status)
    {
        if ($authUser->canDo('status.status.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given status.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Status $status)
    {
        if ($authUser->canDo('status.status.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
